#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MissingH
version:              1.6.0.3
visibility:           public
id:                   MissingH-1.6.0.3-Iwlt5XsWmUT78vq4iMm4Uy
key:                  MissingH-1.6.0.3-Iwlt5XsWmUT78vq4iMm4Uy
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  94fbe2bf018318929ac1e03902758c54
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/MissingH-1.6.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MissingH-1.6.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MissingH-1.6.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.3-Iwlt5XsWmUT78vq4iMm4Uy
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 hslogger-1.3.2.0-FJ9PaCfbf0YCUzH6JnNXpK
    mtl-2.3.1 network-3.1.4.0-DevQmDdzfIO5CV4T8HvaFG
    network-bsd-2.8.1.0-KcmbLcvrwF64H7KRwYQ9nj
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-73KymbHuW6iEs58fZhAZG5 parsec-3.1.16.1
    process-1.6.19.0 regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

